package com.ruoyi.novel.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ruoyi.novel.domain.NovelChapter;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

// NovelChapterMapper.java
@Mapper
public interface NovelChapterMapper {
    List<NovelChapter> selectChapterListByNovelId(Long novelId);
    NovelChapter selectChapterById(Long chapterId);
    int insertChapter(NovelChapter chapter);
    int updateChapter(NovelChapter chapter);

    List<NovelChapter> selectList(QueryWrapper<NovelChapter> orderByAsc);

    void insert(NovelChapter chapter);

    void updateById(NovelChapter chapter);

    NovelChapter selectById(Long chapterId);

    int deleteBatchIds(List<Long> asList);
}